<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet  [
	<!ENTITY nbsp   "&#160;">
	<!ENTITY copy   "&#169;">
	<!ENTITY reg    "&#174;">
	<!ENTITY trade  "&#8482;">
	<!ENTITY mdash  "&#8212;">
	<!ENTITY ldquo  "&#8220;">
	<!ENTITY rdquo  "&#8221;"> 
	<!ENTITY pound  "&#163;">
	<!ENTITY yen    "&#165;">
	<!ENTITY euro   "&#8364;">
]>

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:svg="http://www.w3.org/2000/svg" 
	xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:st="bitel.billing.common.SummaToString"
	xmlns:utils="ru.bitel.bgbilling.server.util.ServerUtils"
	xmlns:counter="bitel.billing.server.util.exslt.Counter">
	
	<xalan:component prefix="st" functions="summaToString">
		<xalan:script lang="javaclass" src="xalan://bitel.billing.common.SummaToString"/>
	</xalan:component>
	<xalan:component prefix="counter" functions="add set get">
		<xalan:script lang="javaclass" src="xalan://bitel.billing.server.util.exslt.Counter"/>
	</xalan:component>

	<xsl:output encoding="UTF-8" method='xml' indent='yes' />

	<!-- Список атрибутов:
		
	<bill
		contract			Договор
		bill_number			Номер счета
		date				Дата выписки
		payer				Плательщик
		
		total_sum			Итого: Сумма
		total_NDS			Итого: НДС
		total_sum_withNDS	Итого: Всего с НДС
		total_to_pay		Итого к оплате
		
		purpose				Назаначение
	>
			<pay
			//\//\//\//\//\//\//\//\//\//
				pos		Товар
				unit		Ед.
				amount		Кол-во
				price		Цена
				sum			Сумма
				NDS			НДС
				sumWithNDS	Всего с НДС
			//\//\//\//\//\//\//\//\//\//
			/>
			
	</bill>
	-->

	<!-- РЕКВИЗИТЫ -->	
	<xsl:variable name="org_title" select="/data/bill/organization/@title" />
	<xsl:variable name="org_address" select="/data/bill/organization/@address" />
	<xsl:variable name="org_inn" select="concat('ИНН ',/data/bill/organization/@inn)" />
	<xsl:variable name="org_kpp" select="concat('КПП ',/data/bill/organization/@kpp)" />
	<xsl:variable name="org_phone" select="/data/bill/organization/@phone" />
	<xsl:variable name="org_email" select="/data/bill/organization/@email" />
	<xsl:variable name="org_site" select="/data/bill/organization/@site" />
	<xsl:variable name="OKVED" select="'ОКВЭД 82000'" />
	<xsl:variable name="OKPO" select="'ОКПО 45219144'" />

	<xsl:variable name="bank_title" select="/data/bill/bank/@title" />
	<xsl:variable name="bank_account" select="/data/bill/bank/@account" />
	<xsl:variable name="bank_bik" select="/data/bill/bank/@bik" />
	<xsl:variable name="bank_correspondent_account" select="/data/bill/bank/@correspondent_account" />

<!-- 	
	<xsl:variable name="fio" select="/data/bill/user/@name" />
 -->
	<xsl:variable name="fio" select="'Сергеев К.Н.'" />
	<!-- РЕКВИЗИТЫ -->

	<xsl:variable name="currency" select="'рубль'" />

	<xsl:attribute-set name="text">
		<xsl:attribute name="text-align">left</xsl:attribute>
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="start-indent">0.1cm</xsl:attribute>
		<xsl:attribute name="end-indent">0.1cm</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="text_ban">
		<xsl:attribute name="text-align">right</xsl:attribute>
		<xsl:attribute name="font-size">6pt</xsl:attribute>
		<xsl:attribute name="start-indent">0.1cm</xsl:attribute>
		<xsl:attribute name="end-indent">0.1cm</xsl:attribute>
	</xsl:attribute-set>

	<xsl:attribute-set name="text_bold">
		<xsl:attribute name="text-align">left</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="start-indent">0.1cm</xsl:attribute>
		<xsl:attribute name="end-indent">0.1cm</xsl:attribute>
	</xsl:attribute-set>

	<xsl:attribute-set name="text_title">
		<xsl:attribute name="text-align">center</xsl:attribute>
		<xsl:attribute name="font-size">14pt</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="start-indent">0.1cm</xsl:attribute>
		<xsl:attribute name="end-indent">0.1cm</xsl:attribute>
		<xsl:attribute name="space-before">0.3cm</xsl:attribute>
		<xsl:attribute name="space-after">0.2cm</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:attribute-set name="text_italic">
		<xsl:attribute name="text-align">left</xsl:attribute>
		<xsl:attribute name="font-size">8pt</xsl:attribute>
		<xsl:attribute name="start-indent">0.1cm</xsl:attribute>
		<xsl:attribute name="end-indent">0.1cm</xsl:attribute>
	</xsl:attribute-set>
	
	<xsl:template match="data">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<xsl:apply-templates select="bill" />
		</fo:root>
	</xsl:template>
	
	<xsl:template match="bill">
		<xsl:variable name="nds_rate" select="number(params/@nds)"/>		
		<xsl:value-of select="counter:set('total_nds', '0.0')"/>

		<fo:layout-master-set>
			<fo:simple-page-master master-name="first"
				margin-left="2cm" margin-right="1cm"
				margin-bottom="1cm" margin-top="2cm"
				page-width="21cm" page-height="29.7cm">
				<fo:region-body margin-top="0cm" margin-bottom="0cm" />
				<fo:region-before extent="0cm" />
				<fo:region-after extent="0cm" />
			</fo:simple-page-master>
		</fo:layout-master-set>

		<xsl:call-template name="calcNDS">
			<xsl:with-param name="nds_rate" select="$nds_rate"/>
		</xsl:call-template>
	
		<fo:page-sequence master-reference="first">	
			<fo:flow flow-name="xsl-region-body" font-family="sans-serif">
			
				<!-- заголовок -->
				<fo:table table-layout="fixed" font-size="7pt">
					<fo:table-column column-width="85mm" />
					<fo:table-column column-width="10mm" />
					<fo:table-column column-width="85mm" />
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell><fo:block font-weight="bold"><xsl:value-of select="$org_title" /></fo:block></fo:table-cell>
							<fo:table-cell><fo:block /></fo:table-cell> 
							<fo:table-cell><fo:block font-size="6pt" text-align="right"><xsl:value-of select="$org_address" /></fo:block><fo:block font-size="6pt" text-align="right">тел.: <xsl:value-of select="$org_phone" /> e-mail: <xsl:value-of select="$org_email" /> web: <xsl:value-of select="$org_site" /></fo:block></fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
				<!-- заголовок -->
		
				<!-- начало таблицы номеров счета, БИК etc. -->
				<fo:table table-layout="fixed" border-collapse="collapse" border-width="0.7pt" border-style="solid" font-size="8pt" space-before="3mm">
					<fo:table-column column-width="60mm" />
					<fo:table-column column-width="60mm" border-right-style="solid" />
					<fo:table-column column-width="13mm" border-right-style="solid" />
					<fo:table-column column-width="47mm" />
		
					<fo:table-body>
						<!-- первая строка -->
						<fo:table-row border-bottom-style="solid">
							<fo:table-cell border-right-style="solid" padding="0.5mm"><fo:block><xsl:value-of select="$org_inn" /></fo:block></fo:table-cell>
							<fo:table-cell padding="0.5mm"><fo:block><xsl:value-of select="$org_kpp" /></fo:block></fo:table-cell>
							<fo:table-cell number-rows-spanned="3" padding="0.5mm"><fo:block>Сч. №</fo:block></fo:table-cell>
							<fo:table-cell number-rows-spanned="3" padding="0.5mm"><fo:block><xsl:value-of select="$bank_account"/></fo:block></fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell number-columns-spanned="2" padding="1mm"><fo:block><xsl:value-of select="$org_title" /></fo:block></fo:table-cell>
						</fo:table-row>
						<fo:table-row height="8pt" border-bottom-style="solid">
							<fo:table-cell number-columns-spanned="2" display-align="after" padding-left="2mm"><fo:block font-size="6pt">Получатель</fo:block></fo:table-cell>
						</fo:table-row>
	
					<!-- вторая строка -->
						<fo:table-row>
							<fo:table-cell number-columns-spanned="2" padding="1mm"><fo:block><xsl:value-of select="$bank_title"/></fo:block></fo:table-cell>
							<fo:table-cell border-bottom-style="solid" padding="0.5mm"><fo:block>БИК</fo:block></fo:table-cell>
							<fo:table-cell border-bottom-style="solid" padding="0.5mm"><fo:block><xsl:value-of select="$bank_bik"/></fo:block></fo:table-cell>
						</fo:table-row>
						<fo:table-row border-bottom-style="solid">
							<fo:table-cell number-columns-spanned="2" display-align="after" padding-left="2mm"><fo:block font-size="6pt">Банк получателя</fo:block></fo:table-cell>
							<fo:table-cell border-bottom-style="solid" padding="0.5mm"><fo:block>Сч. №</fo:block></fo:table-cell>
							<fo:table-cell border-bottom-style="solid" padding="0.5mm"><fo:block><xsl:value-of select="$bank_correspondent_account"/></fo:block></fo:table-cell>
						</fo:table-row>
		
						<!-- третья строка -->
						<fo:table-row height="7mm">
							<fo:table-cell number-columns-spanned="4" padding="1mm" display-align="before"><fo:block display-align="before">Оплата по дог. <xsl:value-of select="@contract"/> и счету <xsl:value-of select="@bill_number" />  от <xsl:value-of select="@date" />. НДС в том числе <xsl:value-of select="utils:formatNumber(number(counter:get('total_nds')), '###,###,##0.00')" /> руб.</fo:block></fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell number-columns-spanned="4" padding-left="2mm" display-align="after"><fo:block font-size="6pt">Назначение платежа</fo:block></fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
				<!-- конец таблицы номеров счета, БИК etc. -->
		
				<fo:block xsl:use-attribute-sets="text" space-before="0.2cm">счет действителен в течении 30 дней</fo:block>
		
				<fo:block space-before="10mm" xsl:use-attribute-sets="text_title">Счет № <xsl:value-of select="@bill_number" /> от <xsl:value-of select="@date" /></fo:block>
		
				<fo:block xsl:use-attribute-sets="text_bold">Плательщик: <xsl:value-of select="/data/bill/attributes/@org_name" /></fo:block>
				
				<fo:table table-layout="fixed">				
					<fo:table-column column-width="150mm"/>
					<fo:table-column column-width="30mm"/>
					
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell><fo:block xsl:use-attribute-sets="text">Договор: <xsl:value-of select="@contract"/></fo:block></fo:table-cell>
							<fo:table-cell><fo:block xsl:use-attribute-sets="text" text-align="right">валюта: <xsl:value-of select="$currency"/></fo:block></fo:table-cell>
						</fo:table-row>
					</fo:table-body>
			</fo:table>
	
			<xsl:call-template name="payList">
				<xsl:with-param name="nds_rate" select="$nds_rate"/>
			</xsl:call-template>
	
			<fo:block xsl:use-attribute-sets="text" space-before="0.1cm">* Цена не включает НДС</fo:block>

			<fo:block space-before="10mm" start-indent="5mm" end-indent="5mm" font-size="8pt" font-weight="bold">Итого к оплате: <xsl:value-of select="st:summaToString(@total_sum)" /></fo:block>	
	
			<xsl:if test="@with_stamp">
				<fo:block start-indent="30mm" space-before="5mm"><fo:external-graphic src="webroot/stamp.gif" width="4.1cm" height="3.85cm" content-height="3.85cm" content-width="4.1cm"/></fo:block>
			</xsl:if>
	
			<fo:table table-layout="fixed" width="150mm" font-size="8pt">
				<xsl:choose>
					<xsl:when test="@with_stamp"><xsl:attribute name="space-before">-26mm</xsl:attribute></xsl:when>
					<xsl:otherwise><xsl:attribute name="space-before">15mm</xsl:attribute></xsl:otherwise>
				</xsl:choose>				
				
				<fo:table-column column-width="30mm"/>
				<fo:table-column column-width="40mm"/>
				<fo:table-column column-width="80mm"/>
				
				<fo:table-body>
				
					<fo:table-row>
						<fo:table-cell><fo:block start-indent="1cm">Счет выдал</fo:block></fo:table-cell>
						<fo:table-cell border-bottom-style="solid" border-bottom-width="0.7pt"><fo:block/></fo:table-cell>
						<fo:table-cell><fo:block start-indent="3mm"> / <xsl:value-of select="$fio"/></fo:block></fo:table-cell>
					</fo:table-row>
					
				</fo:table-body>
			</fo:table>
			
			<fo:block start-indent="20mm" end-indent="20mm" space-before="25mm" text-align="center" font-size="10pt" font-weight="bold">Для своевременного поступления суммы оплаты на Ваш Лицевой счет в платежном поручении просим указывать НОМЕР ДОГОВОРА!</fo:block>
			
		</fo:flow>	
		</fo:page-sequence>		
	</xsl:template>	
		
	<xsl:template name="calcNDS">
		<xsl:param name="nds_rate"/>
	
		<xsl:for-each select="pos">				
				<xsl:variable name="nds" select="number((@summ * ($nds_rate div 100))div($nds_rate div 100 + 1))" />
				<xsl:value-of select="counter:add( 'total_nds', format-number($nds, '0.00') )"/> 
		</xsl:for-each>
	</xsl:template>	
		
	<xsl:template name="payList">		
		<xsl:param name="nds_rate"/>
			
		<!-- начало таблицы счета -->	
		<fo:table table-layout="fixed" border-collapse="collapse" border-width="0.7pt" border-style="solid" font-size="7pt" space-before="3mm">
		
		    <fo:table-column column-width="6mm" border-right-style="solid" />
		    <fo:table-column column-width="66mm" border-right-style="solid" />
		    <fo:table-column column-width="10mm" border-right-style="solid" />
		    <fo:table-column column-width="10mm" border-right-style="solid" />
		    <fo:table-column column-width="22mm" border-right-style="solid" />    	
		    <fo:table-column column-width="22mm" border-right-style="solid" />
		    <fo:table-column column-width="22mm" border-right-style="solid" />
		    <fo:table-column column-width="22mm"/>
		    	    	        	
			<fo:table-header>
				<fo:table-row height="7mm" font-size="6pt" display-align="center" border-bottom-style="solid" text-align="center">
				  	<fo:table-cell><fo:block>№</fo:block></fo:table-cell>
				  	<fo:table-cell><fo:block>Наименование товара (описание работ, услуг), имущественные права</fo:block></fo:table-cell>
				  	<fo:table-cell><fo:block>Ед.</fo:block></fo:table-cell>
				  	<fo:table-cell><fo:block>Кол-во</fo:block></fo:table-cell>
				  	<fo:table-cell><fo:block>Цена *</fo:block></fo:table-cell>
				  	<fo:table-cell><fo:block>Сумма</fo:block></fo:table-cell>
				  	<fo:table-cell><fo:block>НДС</fo:block></fo:table-cell>
				  	<fo:table-cell><fo:block>Всего с НДС</fo:block></fo:table-cell>		    		    		    		    		    
			    </fo:table-row>
			</fo:table-header>
			
			<fo:table-body>
			
				<!-- начало цикл pay -->
				<xsl:for-each select="pos">
				
					<xsl:variable name="nds" select="number((@summ * ($nds_rate div 100))div($nds_rate div 100 + 1))" />
					<!-- <xsl:value-of select="counter:add( 'total_nds', format-number($nds, '0.00') )"/>   -->
					
					<fo:table-row border-bottom-style="solid" text-align="right" start-indent="0.7mm" end-indent="0.7mm">
					  	<fo:table-cell padding="0.5mm"><fo:block><xsl:value-of select="position()"/></fo:block></fo:table-cell>
					  	<fo:table-cell padding="0.5mm"><fo:block text-align="left"><xsl:value-of select="@name"/></fo:block></fo:table-cell>
					  	<fo:table-cell padding="0.5mm"><fo:block><xsl:if test="@unit"><xsl:value-of select="@unit"/></xsl:if><xsl:if test="not(@unit)">месяц</xsl:if></fo:block></fo:table-cell>
					  	<fo:table-cell padding="0.5mm"><fo:block><xsl:if test="@quantity"><xsl:value-of select="@quantity"/></xsl:if><xsl:if test="not(@quantity)">1</xsl:if></fo:block></fo:table-cell>
					  	<fo:table-cell padding="0.5mm"><fo:block><xsl:value-of select="utils:formatNumber(@summ - $nds, '###,###,##0.00')"/></fo:block></fo:table-cell>
					  	<fo:table-cell padding="0.5mm"><fo:block><xsl:value-of select="utils:formatNumber(@summ - $nds, '###,###,##0.00')"/></fo:block></fo:table-cell>
					  	<fo:table-cell padding="0.5mm"><fo:block><xsl:value-of select="utils:formatNumber($nds, '###,###,##0.00')"/></fo:block></fo:table-cell>
					  	<fo:table-cell padding="0.5mm"><fo:block><xsl:value-of select="utils:formatNumber(number(@summ), '###,###,##0.00')"/></fo:block></fo:table-cell>
					</fo:table-row>
		
				</xsl:for-each>
				<!-- конец цикл pos -->
				
				<!-- итого -->
				<fo:table-row text-align="right" font-weight="bold"	start-indent="0.7mm" end-indent="0.7mm">
				  	<fo:table-cell number-columns-spanned="5" padding="0.5mm"><fo:block>Итого:</fo:block></fo:table-cell>
				  	<fo:table-cell padding="0.5mm"><fo:block><xsl:value-of select="utils:formatNumber(@total_sum - counter:get('total_nds'), '###,###,##0.00')"/></fo:block></fo:table-cell>
				  	<fo:table-cell padding="0.5mm"><fo:block><xsl:value-of select="utils:formatNumber(number(counter:get('total_nds')), '###,###,##0.00')"/></fo:block></fo:table-cell>
				  	<fo:table-cell padding="0.5mm"><fo:block><xsl:value-of select="utils:formatNumber(number(@total_sum), '###,###,##0.00')"/></fo:block></fo:table-cell>
				</fo:table-row>
				<!-- итого -->
				
			</fo:table-body>
	
		</fo:table>	
		
		<!-- конец таблицы счета -->
	</xsl:template>
			
	<xsl:template match="pay" mode="pay">
		<xsl:param name="curr_nds"/>

		<xsl:variable name="nds_param" select="params/@nds"/>
		<xsl:variable name="nds_rate_temp" select="number(/data/bill/attributes/@*[name()=$nds_param])"/>

		<xsl:variable name="nds_rate">
			<xsl:choose>
				<xsl:when test="contains($nds_rate_temp,'NaN')">
					<xsl:value-of select="number(/data/bill/params/@default_nds)"/>								
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$nds_rate_temp"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="nds" select="round((@sum * ($nds_rate div 100))div($nds_rate div 100 + 1))" />

		<xsl:choose>
		<xsl:when test="not(following-sibling::*)">
			<xsl:value-of select="$curr_nds + $nds"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="following-sibling::*[position()=1]" mode="pay"><xsl:with-param name="curr_nds" select="$curr_nds + $nds"/></xsl:apply-templates>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:template> 
</xsl:stylesheet>
